@@ -616,6 +616,7 @@ class SyntheticDataBench:
         max_col_nums: int = 50,
         use_ks: bool = False,
         full_sensitivity: bool = True,
+        sensitivity_orig_frac_multiple: int = 3,
     ) -> Union[float, List]:
         """This method implements a bootstrapped estimation of the
         sensitivity values derived from the training data.
@@ -632,6 +633,9 @@ class SyntheticDataBench:
              we expect that the statictic tends to become larger >> 0.
             return_values: Instead of returning a single value based on the `quantile`
              argument, return the full set of boostrap values.
+            sensitivity_orig_frac_multiple: The size of the training data relative to the chosen `frac` that will be
+             used in computing the sensitivity. The larger this value is, the more robust the sensitivity threshold
+             will be. However, `(sensitivity_orig_frac_multiple + 2)` multiplied by `frac` must be less than 1.
         """
         if test_size is not None:
             assert (
@@ -655,6 +659,12 @@ class SyntheticDataBench:
             # We use the full fraction
             frac = 2 * frac
 
+            # We will be sampling data from the dataset that is
+            # `(sensitivity_orig_frac_multiple + 2) * frac` without
+            # replacement. We should make sure that we don't exceed this
+            # threshold.
+            assert ((sensitivity_orig_frac_multiple + 2) * frac <= 1)
+
         for _ in tqdm(range(num_bootstrap), desc="Bootstrap round"):
             if full_sensitivity:
                 original, test = train_test_split(train_data, test_size=2 * frac)
@@ -663,10 +673,15 @@ class SyntheticDataBench:
             else:
                 source: pd.DataFrame = None
                 n_size = int(len(train_data) * frac)
-                _, source = train_test_split(train_data, test_size=3 * frac)
-                original = source.iloc[: n_size]
-                synthetic = source.iloc[n_size: 2 * n_size]
-                test = source.iloc[2 * n_size: 3 * n_size]
+                n_train_size = sensitivity_orig_frac_multiple * n_size
+                test_size = n_train_size + (2 * n_size)
+
+                _, source = train_test_split(train_data, test_size=test_size)
+                original = source.iloc[: n_train_size]
+                synthetic = source.iloc[n_train_size: n_train_size + n_size]
+                test = source.iloc[n_train_size + n_size:]
+
+                assert synthetic.shape[0] == test.shape[0]
 
             values.append(
                 SyntheticDataBench.compute_sensitivity_metric(
