@@ -147,6 +147,20 @@ class REaLSampler:
                         series.loc[
                             series.str.contains(re_invalid_pattern, regex=True)
                         ] = "NaN"
+                elif pd.api.types.is_object_dtype(d):
+                    # In case the values in this column is "integral"
+                    # but are cast as object in the real data, let's try
+                    # to convert them first to int before casting to the
+                    # correct object type.
+                    # Not doing this will incorrectly generate "float"-looking
+                    # data for object types, but are integral, in the
+                    # fb-comments dataset.
+                    try:
+                        series = series.astype(pd.Int64Dtype())
+                    except TypeError:
+                        pass
+                    except ValueError:
+                        pass
 
                 _synth_df.append(series.astype(d))
             except Exception:  # nolint
